# eric7.eric7config

Module containing the default configuration of the eric installation.

### Global Attributes

__ericDir
_pkg_config

### Classes

None

### Functions

getConfig | Module function to get a configuration value.

## getConfig

getConfig(name)

Module function to get a configuration value.

name (str)
  name of the configuration value

Return:
  requested config value

Return Type:
  str

Raises AttributeError:
  raised to indicate an invalid config entry

Up